import {
  apiUrl
} from "./chunk-25AKG5HH.js";
import {
  ALL_DEVICES,
  ALL_RELEASES,
  DEVICE_FILTERING_OPTIONS,
  DEVICE_LIST_DEFAULTS,
  EXTERNAL_PROVIDER,
  SORTING_OPTIONS,
  emptyUiPermissions
} from "./chunk-4B3IMP4I.js";

// src/devicesSlice/constants.ts
var emptyFilter = { key: null, value: "", operator: DEVICE_FILTERING_OPTIONS.$eq.key, scope: "inventory" };
var deviceAuthV2 = `${apiUrl.v2}/devauth`;
var deviceConnect = `${apiUrl.v1}/deviceconnect`;
var inventoryApiUrl = `${apiUrl.v1}/inventory`;
var inventoryApiUrlV2 = `${apiUrl.v2}/inventory`;
var deviceConfig = `${apiUrl.v1}/deviceconfig/configurations/device`;
var reportingApiUrl = `${apiUrl.v1}/reporting`;
var iotManagerBaseURL = `${apiUrl.v1}/iot-manager`;
var DEVICE_MESSAGE_PROTOCOLS = {
  Shell: 1
};
var DEVICE_MESSAGE_TYPES = {
  Delay: "delay",
  New: "new",
  Ping: "ping",
  Pong: "pong",
  Resize: "resize",
  Shell: "shell",
  Stop: "stop"
};
var DEVICE_DISMISSAL_STATE = "dismiss";
var ALL_DEVICE_STATES = "any";
var DEVICE_STATES = {
  accepted: "accepted",
  pending: "pending",
  preauth: "preauthorized",
  rejected: "rejected"
};
var DEVICE_CONNECT_STATES = {
  connected: "connected",
  disconnected: "disconnected",
  unknown: "unknown"
};
var geoAttributes = ["geo-lat", "geo-lon"].map((attribute) => ({ attribute, scope: "inventory" }));

// src/monitorSlice/constants.ts
var alertChannels = { email: "email" };
var monitorApiUrlv1 = `${apiUrl.v1}/devicemonitor`;

// src/organizationSlice/constants.ts
var auditLogsApiUrl = `${apiUrl.v1}/auditlogs`;
var tenantadmApiUrlv1 = `${apiUrl.v1}/tenantadm`;
var tenantadmApiUrlv2 = `${apiUrl.v2}/tenantadm`;
var ssoIdpApiUrlv1 = `${apiUrl.v1}/useradm/sso/idp/metadata`;
var XML_METADATA_FORMAT = "xml";
var JSON_METADATA_FORMAT = "json";
var getSamlStartUrl = (id) => `${window.location.origin}${useradmApiUrlv1}/auth/sso/${id}/login`;
var getOidcStartUrl = (id) => `${window.location.origin}${useradmApiUrlv1}/oidc/${id}/start`;
var SSO_TYPES = {
  saml: {
    id: "saml",
    type: "saml",
    title: "SAML",
    metadataFormat: XML_METADATA_FORMAT,
    editorLanguage: XML_METADATA_FORMAT,
    contentType: "application/samlmetadata+xml",
    getStartUrl: getSamlStartUrl,
    configDetails: [
      { key: "entityID", label: "Entity ID", getValue: (id) => `${window.location.origin}${useradmApiUrlv1}/sso/sp/metadata/${id}` },
      { key: "acs", label: "ACS URL", getValue: (id) => `${window.location.origin}${useradmApiUrlv1}/auth/sso/${id}/acs` },
      { key: "startURL", label: "Start URL", getValue: getSamlStartUrl }
    ]
  },
  oidc: {
    id: "oidc",
    type: "oidc",
    title: "OpenID Connect",
    metadataFormat: JSON_METADATA_FORMAT,
    editorLanguage: JSON_METADATA_FORMAT,
    contentType: "application/json",
    getStartUrl: getOidcStartUrl,
    configDetails: [{ key: "startURL", label: "Start Url", getValue: getOidcStartUrl }]
  }
};
var AUDIT_LOGS_TYPES = [
  { title: "Artifact", queryParameter: "object_type", value: "artifact" },
  { title: "Deployment", queryParameter: "object_deployment_name", value: "deployment" },
  { title: "Device", queryParameter: "object_id", value: "device" },
  { title: "User", queryParameter: "object_id", value: "user" }
];
var SP_AUDIT_LOGS_TYPES = [AUDIT_LOGS_TYPES[3], { title: "Tenant", queryParameter: "object_id", value: "tenant" }];
var emptyWebhook = {
  description: "",
  enabled: true,
  credentials: {
    type: EXTERNAL_PROVIDER.webhook.credentialsType,
    [EXTERNAL_PROVIDER.webhook.credentialsType]: {
      secret: "",
      url: ""
    }
  }
};
var TENANT_LIST_DEFAULT = {
  page: 1,
  perPage: 20
};

// src/usersSlice/constants.ts
var useradmApiUrlv1 = `${apiUrl.v1}/useradm`;
var useradmApiUrlv2 = `${apiUrl.v2}/useradm`;
var staticRolesByName = {
  admin: "RBAC_ROLE_PERMIT_ALL",
  readOnly: "RBAC_ROLE_OBSERVER",
  ci: "RBAC_ROLE_CI",
  deploymentsManager: "RBAC_ROLE_DEPLOYMENTS_MANAGER",
  terminalAccess: "RBAC_ROLE_REMOTE_TERMINAL"
};
var PermissionTypes = {
  Any: "any",
  Get: "GET",
  Post: "POST",
  Put: "PUT",
  Delete: "DELETE",
  Patch: "PATCH",
  DeviceGroup: "DEVICE_GROUP",
  DeviceId: "DEVICE_ID"
};
var permissionSetIds = {
  Basic: "Basic",
  ConfigureDevices: "ConfigureDevices",
  ConnectToDevices: "ConnectToDevices",
  DeployToDevices: "DeployToDevices",
  ManageDevices: "ManageDevices",
  ManageReleases: "ManageReleases",
  ManageTenants: "ManageTenants",
  ManageUsers: "ManageUsers",
  ReadAuditLogs: "ReadAuditLogs",
  ReadDevices: "ReadDevices",
  ReadReleases: "ReadReleases",
  ReadTenants: "ReadTenants",
  ReadUsers: "ReadUsers",
  SuperUser: "SuperUser",
  UploadArtifacts: "UploadArtifacts"
};
var uiPermissionsById = {
  configure: {
    explanations: { groups: `'Configure' allows the user to use mender-configure features and apply configurations.` },
    permissionLevel: 2,
    permissionSets: { groups: permissionSetIds.ConfigureDevices },
    title: "Configure",
    value: "configure",
    verbs: [PermissionTypes.Get, PermissionTypes.Put, PermissionTypes.Post]
  },
  connect: {
    explanations: { groups: `'Connect' allows the user to use mender-connect features and Troubleshoot add-ons.` },
    permissionLevel: 2,
    permissionSets: { groups: permissionSetIds.ConnectToDevices },
    title: "Connect",
    value: "connect",
    verbs: [PermissionTypes.Get, PermissionTypes.Put]
  },
  deploy: {
    explanations: { groups: `'Deploy' allows the user to deploy software or configuration updates to devices.` },
    permissionLevel: 2,
    permissionSets: { deployments: permissionSetIds.DeployToDevices, groups: permissionSetIds.DeployToDevices },
    title: "Deploy",
    value: "deploy",
    verbs: [PermissionTypes.Post]
  },
  manage: {
    explanations: {
      groups: `'Manage' allows the user to edit device name, notes, and manage authentication status. For 'All devices' it also allows the user to edit and create device groups.`,
      releases: `'Manage' allows the user to upload new artifacts, edit release descriptions and remove artifacts.`
    },
    permissionLevel: 2,
    permissionSets: {
      groups: permissionSetIds.ManageDevices,
      releases: permissionSetIds.ManageReleases,
      tenantManagement: permissionSetIds.ManageTenants,
      userManagement: permissionSetIds.ManageUsers
    },
    title: "Manage",
    value: "manage",
    verbs: [PermissionTypes.Post, PermissionTypes.Put, PermissionTypes.Patch]
  },
  read: {
    explanations: { groups: `'Read' allows the user to view devices.` },
    permissionLevel: 1,
    permissionSets: {
      auditlog: permissionSetIds.ReadAuditLogs,
      groups: permissionSetIds.ReadDevices,
      releases: permissionSetIds.ReadReleases,
      tenantManagement: permissionSetIds.ReadTenants,
      userManagement: permissionSetIds.ReadUsers
    },
    title: "Read",
    value: "read",
    verbs: [PermissionTypes.Get, PermissionTypes.Post]
  },
  upload: {
    explanations: { groups: `'Upload' allows the user to upload new Artifacts.` },
    unscopedOnly: { releases: true },
    permissionLevel: 1,
    permissionSets: { releases: permissionSetIds.UploadArtifacts },
    title: "Upload",
    value: "upload",
    verbs: [PermissionTypes.Post, PermissionTypes.Put, PermissionTypes.Patch]
  }
};
var scopedPermissionAreas = {
  groups: { key: "groups", excessiveAccessSelector: ALL_DEVICES, scopeType: "DeviceGroups" },
  releases: { key: "releases", excessiveAccessSelector: ALL_RELEASES, scopeType: "Releases" }
};
var uiPermissionsByArea = {
  auditlog: {
    endpoints: [{ path: /\/(auditlog)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.read] }],
    explanation: "Granting access to the audit log will allow tracing changes to devices, releases and user accounts, as well as providing information about deployments.",
    key: "auditlog",
    uiPermissions: [uiPermissionsById.read],
    title: "System audit log"
  },
  deployments: {
    endpoints: [
      { path: /\/(deployments\/deployments)/i, types: [PermissionTypes.Post, PermissionTypes.Put], uiPermissions: [uiPermissionsById.deploy] },
      { path: /\/(deployments\/deployments)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.read] },
      { path: /\/(deployments\/config)/i, types: [PermissionTypes.Get, PermissionTypes.Put], uiPermissions: [uiPermissionsById.manage] }
    ],
    explanation: "Providing deploy permissions will allow deployments to be created using the releases and devices a user has access to.",
    key: "deployments",
    uiPermissions: [uiPermissionsById.read, uiPermissionsById.deploy],
    title: "Deployments"
  },
  groups: {
    endpoints: [
      {
        path: /\/(devauth|inventory|deviceconfig|devicemonitor|deviceconnect\/devices)/i,
        types: [PermissionTypes.Get],
        uiPermissions: [uiPermissionsById.read]
      },
      { path: /\/(devauth|inventory)/i, types: [PermissionTypes.Put, PermissionTypes.Post], uiPermissions: [uiPermissionsById.manage] },
      { path: /\/(deviceconfig)/i, types: [PermissionTypes.Get, PermissionTypes.Put, PermissionTypes.Post], uiPermissions: [uiPermissionsById.configure] },
      { path: /\/(deviceconnect\/devices)/i, types: [PermissionTypes.Get, PermissionTypes.Post], uiPermissions: [uiPermissionsById.connect] }
    ],
    explanation: "Device group management permissions control the degree to which devices in a group can be accessed and moved to other groups.",
    key: "groups",
    scope: scopedPermissionAreas.groups.scopeType,
    uiPermissions: [uiPermissionsById.read, uiPermissionsById.manage, uiPermissionsById.deploy, uiPermissionsById.configure, uiPermissionsById.connect],
    title: "Group Management"
  },
  releases: {
    endpoints: [
      { path: /\/(deployments\/artifacts|deployments\/deployments\/releases)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.read] },
      {
        path: /\/(deployments\/artifacts|deployments\/deployments\/releases)/i,
        types: [PermissionTypes.Post, PermissionTypes.Put],
        uiPermissions: [uiPermissionsById.read, uiPermissionsById.upload]
      },
      {
        path: /\/(deployments\/artifacts|deployments\/deployments\/releases)/i,
        types: [PermissionTypes.Delete],
        uiPermissions: [uiPermissionsById.read, uiPermissionsById.manage]
      }
    ],
    explanation: "Release permissions can be granted to allow artifact & release modifications, as well as the creation of new releases.",
    key: "releases",
    scope: "ReleaseTags",
    uiPermissions: [uiPermissionsById.read, uiPermissionsById.manage, uiPermissionsById.upload],
    title: "Release Management"
  },
  tenantManagement: {
    endpoints: [
      { path: /\/(tenantadm\/tenants)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.read] },
      { path: /\/(tenantadm\/tenants)/i, types: [PermissionTypes.Post, PermissionTypes.Put], uiPermissions: [uiPermissionsById.manage] },
      { path: /\/(users\/exists)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.manage] }
    ],
    explanation: "Tenant management permissions allow listing, creating and modifying child tenants",
    key: "tenantManagement",
    uiPermissions: [uiPermissionsById.read, uiPermissionsById.manage],
    title: "Tenant Management"
  },
  userManagement: {
    endpoints: [
      { path: /\/(useradm)/i, types: [PermissionTypes.Get], uiPermissions: [uiPermissionsById.read] },
      { path: /\/(useradm)/i, types: [PermissionTypes.Post], uiPermissions: [uiPermissionsById.manage] }
    ],
    explanation: "User management permissions should be granted carefully, as these allow privilege increases for any users managed by a user with user management permissions",
    key: "userManagement",
    uiPermissions: [uiPermissionsById.read, uiPermissionsById.manage],
    title: "User Management"
  }
};
var permissionMapper = (permission) => permission.value;
var itemUiPermissionsReducer = (accu, { item, uiPermissions }) => item ? { ...accu, [item]: uiPermissions } : accu;
var checkSinglePermission = (permission, requiredPermission) => requiredPermission === permission || uiPermissionsById[permission].permissionLevel > uiPermissionsById[requiredPermission].permissionLevel;
var checkPermissionsObject = (permissions, requiredPermission, scopedAccess, superAccess) => permissions[superAccess]?.some((permission) => checkSinglePermission(permission, requiredPermission)) || permissions[scopedAccess]?.some((permission) => checkSinglePermission(permission, requiredPermission));
var rolesById = Object.freeze({
  [staticRolesByName.admin]: {
    name: "Admin",
    value: staticRolesByName.admin,
    description: "Full access",
    permissions: [],
    // permissions refers to the values returned from the backend
    uiPermissions: {
      ...emptyUiPermissions,
      auditlog: uiPermissionsByArea.auditlog.uiPermissions.map(permissionMapper),
      deployments: uiPermissionsByArea.deployments.uiPermissions.map(permissionMapper),
      groups: { [ALL_DEVICES]: uiPermissionsByArea.groups.uiPermissions.map(permissionMapper) },
      releases: { [ALL_RELEASES]: uiPermissionsByArea.releases.uiPermissions.map(permissionMapper) },
      userManagement: uiPermissionsByArea.userManagement.uiPermissions.map(permissionMapper)
    }
  },
  [staticRolesByName.readOnly]: {
    name: "Read Access",
    value: staticRolesByName.readOnly,
    description: "",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      deployments: [uiPermissionsById.read.value],
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value] },
      releases: { [ALL_RELEASES]: [uiPermissionsById.read.value] },
      userManagement: [uiPermissionsById.read.value]
    }
  },
  [staticRolesByName.ci]: {
    name: "Releases Manager",
    value: staticRolesByName.ci,
    description: "",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      releases: { [ALL_RELEASES]: uiPermissionsByArea.releases.uiPermissions.map(permissionMapper) }
    }
  },
  [staticRolesByName.deploymentsManager]: {
    name: "Deployments Manager",
    value: staticRolesByName.deploymentsManager,
    description: "",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      deployments: uiPermissionsByArea.deployments.uiPermissions.map(permissionMapper),
      groups: { [ALL_DEVICES]: [uiPermissionsById.deploy.value, uiPermissionsById.read.value] },
      releases: { [ALL_RELEASES]: [uiPermissionsById.read.value] }
    }
  },
  [staticRolesByName.terminalAccess]: {
    name: "Troubleshooting",
    value: staticRolesByName.terminalAccess,
    description: "Access to the troubleshooting features: Remote Terminal, File Transfer, Port Forwarding",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      groups: { [ALL_DEVICES]: [uiPermissionsById.connect.value] }
    }
  }
});
var serviceProviderRolesById = {
  admin: {
    name: "Admin",
    value: staticRolesByName.admin,
    description: "Full access",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      auditlog: uiPermissionsByArea.auditlog.uiPermissions.map(permissionMapper),
      userManagement: uiPermissionsByArea.userManagement.uiPermissions.map(permissionMapper),
      tenantManagement: uiPermissionsByArea.tenantManagement.uiPermissions.map(permissionMapper)
    }
  },
  readOnly: {
    name: "Read access",
    value: staticRolesByName.admin,
    description: "This role can see all linked organizations but cannot make any changes",
    permissions: [],
    uiPermissions: {
      ...emptyUiPermissions,
      auditlog: [uiPermissionsById.read.value],
      userManagement: [uiPermissionsById.read.value],
      tenantManagement: [uiPermissionsById.read.value]
    }
  }
};
var defaultPermissionSets = {
  [permissionSetIds.Basic]: {
    name: permissionSetIds.Basic,
    result: {
      // this is needed to prevent the detailed permissions of the basic permission set from being interpreted as allowing read & management access to user endpoints
      userManagement: [uiPermissionsById.read.value]
    }
  },
  [permissionSetIds.SuperUser]: {
    name: permissionSetIds.SuperUser,
    result: {
      ...rolesById[staticRolesByName.admin].uiPermissions
    }
  },
  [permissionSetIds.ManageUsers]: {
    name: permissionSetIds.ManageUsers,
    result: {
      userManagement: [uiPermissionsById.manage.value]
    }
  },
  [permissionSetIds.ReadAuditLogs]: {
    name: permissionSetIds.ReadAuditLogs,
    result: {
      auditlog: [uiPermissionsById.read.value]
    }
  },
  [permissionSetIds.ReadReleases]: {
    name: permissionSetIds.ReadReleases,
    result: {
      releases: { [ALL_RELEASES]: [uiPermissionsById.read.value] }
    }
  },
  [permissionSetIds.ReadTenants]: {
    name: permissionSetIds.ReadTenants,
    result: {
      tenantManagement: [uiPermissionsById.read.value]
    }
  },
  [permissionSetIds.ManageTenants]: {
    name: permissionSetIds.ManageTenants,
    result: {
      tenantManagement: [uiPermissionsById.manage.value]
    }
  },
  [permissionSetIds.ReadUsers]: {
    name: permissionSetIds.ReadUsers,
    result: {
      userManagement: [uiPermissionsById.read.value]
    }
  },
  [permissionSetIds.UploadArtifacts]: {
    name: permissionSetIds.UploadArtifacts,
    result: {
      releases: { [ALL_RELEASES]: [uiPermissionsById.upload.value] }
    }
  },
  [permissionSetIds.ManageReleases]: {
    name: permissionSetIds.ManageReleases,
    result: {
      releases: { [ALL_RELEASES]: [uiPermissionsById.manage.value] }
    }
  },
  [permissionSetIds.ConfigureDevices]: {
    name: permissionSetIds.ConfigureDevices,
    result: {
      deployments: [uiPermissionsById.read.value, uiPermissionsById.deploy.value],
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value, uiPermissionsById.configure.value] }
    }
  },
  [permissionSetIds.ConnectToDevices]: {
    name: permissionSetIds.ConnectToDevices,
    result: {
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value, uiPermissionsById.connect.value] }
    }
  },
  [permissionSetIds.DeployToDevices]: {
    name: permissionSetIds.DeployToDevices,
    result: {
      deployments: [uiPermissionsById.deploy.value, uiPermissionsById.manage.value, uiPermissionsById.read.value],
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value, uiPermissionsById.deploy.value] }
    }
  },
  [permissionSetIds.ManageDevices]: {
    name: permissionSetIds.ManageDevices,
    result: {
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value, uiPermissionsById.manage.value] }
    }
  },
  [permissionSetIds.ReadDevices]: {
    name: permissionSetIds.ReadDevices,
    result: {
      groups: { [ALL_DEVICES]: [uiPermissionsById.read.value] }
    }
  }
};
var USER_LOGOUT = "USER_LOGOUT";
var OWN_USER_ID = "me";
var rolesByName = {
  ...staticRolesByName,
  deploymentCreation: { action: "CREATE_DEPLOYMENT", object: { type: "DEVICE_GROUP", value: void 0 } },
  groupAccess: { action: "VIEW_DEVICE", object: { type: "DEVICE_GROUP", value: void 0 } },
  userManagement: { action: "http", object: { type: "any", value: `${useradmApiUrlv1}/.*` } }
};
var twoFAStates = {
  enabled: "enabled",
  disabled: "disabled",
  unverified: "unverified"
};
var settingsKeys = { initialized: "settings-initialized" };
var READ_STATES = {
  read: "read",
  seen: "seen",
  unread: "unread"
};

// src/deploymentsSlice/constants.ts
var alreadyInstalled = "already-installed";
var deploymentsApiUrl = `${apiUrl.v1}/deployments`;
var deploymentsApiUrlV2 = `${apiUrl.v2}/deployments`;
var deploymentSubstates = {
  aborted: "aborted",
  alreadyInstalled,
  decommissioned: "decommissioned",
  downloading: "downloading",
  failure: "failure",
  installing: "installing",
  noartifact: "noartifact",
  pause_before_committing: "pause_before_committing",
  pause_before_installing: "pause_before_installing",
  pause_before_rebooting: "pause_before_rebooting",
  pending: "pending",
  rebooting: "rebooting",
  success: "success"
};
var deploymentStatesToSubstates = {
  failures: [deploymentSubstates.failure, deploymentSubstates.aborted, deploymentSubstates.decommissioned],
  inprogress: [deploymentSubstates.downloading, deploymentSubstates.installing, deploymentSubstates.rebooting],
  paused: [deploymentSubstates.pause_before_installing, deploymentSubstates.pause_before_rebooting, deploymentSubstates.pause_before_committing],
  pending: [deploymentSubstates.pending],
  successes: [deploymentSubstates.success, deploymentSubstates.alreadyInstalled, deploymentSubstates.noartifact]
};
var deploymentStatesToSubstatesWithSkipped = {
  ...deploymentStatesToSubstates,
  failures: [deploymentSubstates.failure],
  skipped: [deploymentSubstates.aborted, deploymentSubstates.noartifact, deploymentSubstates.alreadyInstalled, deploymentSubstates.decommissioned],
  successes: [deploymentSubstates.success]
};
var installationSubstatesMap = {
  download: {
    title: "download",
    done: "downloaded",
    successIndicators: [deploymentSubstates.installing, deploymentSubstates.rebooting, ...deploymentStatesToSubstates.paused, deploymentSubstates.success],
    failureIndicators: deploymentStatesToSubstates.failures,
    pauseConfigurationIndicator: "ArtifactInstall_Enter"
  },
  install: {
    title: "install",
    done: "installed",
    successIndicators: [
      deploymentSubstates.rebooting,
      deploymentSubstates.pause_before_rebooting,
      deploymentSubstates.pause_before_committing,
      deploymentSubstates.success
    ],
    failureIndicators: deploymentStatesToSubstates.failures,
    pauseConfigurationIndicator: "ArtifactReboot_Enter"
  },
  reboot: {
    title: "reboot",
    done: "rebooted",
    successIndicators: [deploymentSubstates.pause_before_committing, deploymentSubstates.success],
    failureIndicators: deploymentStatesToSubstates.failures,
    pauseConfigurationIndicator: "ArtifactCommit_Enter"
  },
  commit: {
    title: "commit",
    done: "committed",
    successIndicators: deploymentStatesToSubstates.successes,
    failureIndicators: deploymentStatesToSubstates.failures,
    pauseConfigurationIndicator: void 0
  }
};
var DEPLOYMENT_STATES = {
  finished: "finished",
  inprogress: "inprogress",
  pending: "pending",
  scheduled: "scheduled"
};
var listDefaultsByState = {
  [DEPLOYMENT_STATES.inprogress]: { page: 1, perPage: 10 },
  [DEPLOYMENT_STATES.pending]: { page: 1, perPage: 10 },
  [DEPLOYMENT_STATES.scheduled]: { ...DEVICE_LIST_DEFAULTS },
  [DEPLOYMENT_STATES.finished]: { ...DEVICE_LIST_DEFAULTS },
  sort: { direction: SORTING_OPTIONS.desc }
};
var DEFAULT_PENDING_INPROGRESS_COUNT = 10;
var DEPLOYMENT_ROUTES = {
  active: {
    key: "active",
    route: "/deployments/active",
    states: [DEPLOYMENT_STATES.pending, DEPLOYMENT_STATES.inprogress],
    title: "Active"
  },
  finished: {
    key: "finished",
    route: "/deployments/finished",
    states: [DEPLOYMENT_STATES.finished],
    title: "Finished"
  },
  scheduled: {
    key: "scheduled",
    route: "/deployments/scheduled",
    states: [DEPLOYMENT_STATES.scheduled],
    title: "Scheduled"
  }
};
var DEPLOYMENT_TYPES = {
  software: "software",
  configuration: "configuration"
};
var defaultStats = {
  [deploymentSubstates.aborted]: 0,
  [deploymentSubstates.alreadyInstalled]: 0,
  [deploymentSubstates.decommissioned]: 0,
  [deploymentSubstates.downloading]: 0,
  [deploymentSubstates.failure]: 0,
  [deploymentSubstates.installing]: 0,
  [deploymentSubstates.noartifact]: 0,
  [deploymentSubstates.pause_before_committing]: 0,
  [deploymentSubstates.pause_before_installing]: 0,
  [deploymentSubstates.pause_before_rebooting]: 0,
  [deploymentSubstates.pending]: 0,
  [deploymentSubstates.rebooting]: 0,
  [deploymentSubstates.success]: 0
};
var deploymentDisplayStates = {
  finished: "Finished",
  scheduled: "Scheduled",
  skipped: "Skipped",
  paused: "Paused",
  pending: "Pending",
  inprogress: "In Progress",
  success: "Success",
  successes: "Success",
  failure: "Fail",
  failures: "Fail"
};
var deploymentPrototype = {
  devices: {},
  name: void 0,
  statistics: { status: {} }
};
var pauseMap = {
  [deploymentSubstates.pause_before_installing]: {
    title: installationSubstatesMap.download.done,
    followUp: installationSubstatesMap.download.pauseConfigurationIndicator
  },
  [deploymentSubstates.pause_before_rebooting]: {
    title: installationSubstatesMap.install.done,
    followUp: installationSubstatesMap.install.pauseConfigurationIndicator
  },
  [deploymentSubstates.pause_before_committing]: {
    title: installationSubstatesMap.reboot.done,
    followUp: installationSubstatesMap.reboot.pauseConfigurationIndicator
  }
};
var limitDefault = { min: 5, max: 100, default: 10 };

export {
  deploymentsApiUrl,
  deploymentsApiUrlV2,
  deploymentSubstates,
  deploymentStatesToSubstates,
  deploymentStatesToSubstatesWithSkipped,
  installationSubstatesMap,
  DEPLOYMENT_STATES,
  listDefaultsByState,
  DEFAULT_PENDING_INPROGRESS_COUNT,
  DEPLOYMENT_ROUTES,
  DEPLOYMENT_TYPES,
  defaultStats,
  deploymentDisplayStates,
  deploymentPrototype,
  pauseMap,
  limitDefault,
  emptyFilter,
  deviceAuthV2,
  deviceConnect,
  inventoryApiUrl,
  inventoryApiUrlV2,
  deviceConfig,
  reportingApiUrl,
  iotManagerBaseURL,
  DEVICE_MESSAGE_PROTOCOLS,
  DEVICE_MESSAGE_TYPES,
  DEVICE_DISMISSAL_STATE,
  ALL_DEVICE_STATES,
  DEVICE_STATES,
  DEVICE_CONNECT_STATES,
  geoAttributes,
  alertChannels,
  monitorApiUrlv1,
  auditLogsApiUrl,
  tenantadmApiUrlv1,
  tenantadmApiUrlv2,
  ssoIdpApiUrlv1,
  XML_METADATA_FORMAT,
  JSON_METADATA_FORMAT,
  getSamlStartUrl,
  getOidcStartUrl,
  SSO_TYPES,
  AUDIT_LOGS_TYPES,
  SP_AUDIT_LOGS_TYPES,
  emptyWebhook,
  TENANT_LIST_DEFAULT,
  useradmApiUrlv1,
  useradmApiUrlv2,
  PermissionTypes,
  uiPermissionsById,
  scopedPermissionAreas,
  uiPermissionsByArea,
  itemUiPermissionsReducer,
  checkPermissionsObject,
  rolesById,
  serviceProviderRolesById,
  defaultPermissionSets,
  USER_LOGOUT,
  OWN_USER_ID,
  rolesByName,
  twoFAStates,
  settingsKeys,
  READ_STATES
};
//# sourceMappingURL=chunk-A6CT6GTI.js.map